from django.conf import settings
import os


def get_app_path(app_name):
    """
    Returns app path from django apps
    :param app_name: the name of the app to search
    :return: app path
    """
    return os.path.join(settings.BASE_DIR, app_name)


def app_exists(app_name):
    """
    Validates if the app exists
    :param app_name: the app name to validate
    :return: True/False (Boolean)
    """
    return os.path.exists(get_app_path(app_name))


def get_tests_file(app_name, file_name, data=""):
    """
    Returns the app test file if exists else creates a new test
    file and return it path
    :param app_name: the app to search for test file in
    :param file_name: the file name
    :param data: the data of the test file
    :return: path of file (str), data (str)
    """
    # if app not exists
    if not app_exists(app_name):
        return None, None
    # building test file path
    path = os.path.join(get_app_path(app_name), file_name)
    # if test file not exists generating new
    if not os.path.exists(path):
        with open(path, 'w+') as file:
            file.write(data)
    # if test file exists reading the test file data
    else:
        with open(path, 'r') as file:
            data = file.read()
    # returns path (str), data (str)
    return path, data


def register_unitest():
    """
    Register django env to know it's under a test
    :return: None
    """
    os.environ['under_test'] = "True"


def in_test():
    """
    Check if django is under a test
    :return: True/False (boolean)
    """
    return bool(os.environ.get('under_test'))



from django.views.generic import TemplateView
from django.http import HttpResponse
import json


class TemplateContextFetcherView(TemplateView):
    def post_method_override(self, *args, **kwargs):
        return HttpResponse("To override the post method declare post_method_override in your view - django-easy-rest")

    def post(self, request, *args, **kwargs):
        """

        :param request: WSGI request
        :param args:
        :param kwargs:
        :return: HttpResponse containing updated context
        """

        action = request.POST.get("action", "")
        if action == "fetch-content":
            return HttpResponse(json.dumps(self.get_context_data(request=request)))

        return self.post_method_override(request, *args, **kwargs)



import os
from setuptools import find_packages, setup

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
try:
    import pypandoc

    README = pypandoc.convert(os.path.join(os.path.dirname(__file__), 'README.md'), 'rst')
except (ImportError, OSError):
    README = ""
setup(
    name='django-easy-rest',
    version='1.09',
    packages=find_packages(),
    include_package_data=True,
    install_requires=['djangorestframework', 'django'],
    license='MIT License',
    description='A simple Django app to create rest applications',
    long_description=README,
    url='https://github.com/jonatanSh/django-easy-rest/',
    author='Jonathan Shimon',
    author_email='jonatanshimon@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
